@@ -6,13 +6,17 @@ Information on the Adamax optimizer
 
 # Standard
 from dataclasses import dataclass
-
-# Third-party
-import tensorflow as tf
+from typing import List
 
 # Locals
-from .optimizer import OptimizerParameters
+from .._imports import try_import
 from .adapters.tensorflow_implementations import TensorflowOptimizer
+from .optimizer import OptimizerParameters
+
+# Third-party extension
+with try_import('optimization') as _imports:
+    import tensorflow as tf
+
 
 #                                                          Authorship & Credits
 # =============================================================================
@@ -46,3 +50,6 @@ class Adamax(TensorflowOptimizer):
             beta_2=self.parameter.beta_2,
             epsilon=self.parameter.epsilon,
         )
+
+    def get_info(self) -> List[str]:
+        return ['Fast', 'Single-Solution']
