@@ -3,17 +3,20 @@
 
 # Standard
 from dataclasses import dataclass
-from typing import Any, Tuple
+from typing import Any, List, Tuple
 
-# Third-party
+# Third-party core
 import autograd.numpy as np
-import pygmo as pg
 
 # Locals
-# from ...base.optimization import Optimizer
+from ..._imports import try_import
 from .._protocol import DesignSpace, Function
 from ..optimizer import Optimizer
 
+# Third-party extension
+with try_import('optimization') as _imports:
+    import pygmo as pg
+
 #                                                          Authorship & Credits
 # =============================================================================
 __author__ = 'Martin van der Schelling (M.P.vanderSchelling@tudelft.nl)'
@@ -25,14 +28,19 @@ __status__ = 'Stable'
 
 
 @dataclass
-class PygmoProblem:
-    """Convert a testproblem from problemset to a pygmo object
+class _PygmoProblem:
+    """Convert a testproblem from the problemset to pygmo object
 
-    :param design: Designspace
-    :param func: function to be evaluated
-    :param seed: seed for the random number generator
+    Parameters
+    ----------
+    design
+        designspace to be used
+    func
+        function to be evaluated
+    seed
+        seed for the random number generator
+        _description_
     """
-
     design: DesignSpace
     func: Function
     seed: Any or int = None
@@ -44,22 +52,34 @@ class PygmoProblem:
     def fitness(self, x: np.ndarray) -> np.ndarray:
         """Pygmo representation of returning the objective value of a function
 
-        :param x: input vector
-        :return: fitness
+        Parameters
+        ----------
+        x
+            input vector
+
+        Returns
+        -------
+            fitness
         """
         return self.func(x).ravel()  # pygmo doc: should output 1D numpy array
 
     def batch_fitness(self, x: np.ndarray) -> np.ndarray:
         """Pygmo representation of returning multiple objective values of a function
 
-        :param x: input vectors
-        :return: fitnesses
+        Parameters
+        ----------
+        x
+            input vectors
+
+        Returns
+        -------
+            fitnesses
         """
         # Pygmo representation of returning multiple objective values of a function
         return self.fitness(x)
 
-    def get_bounds(self) -> tuple:
-        """Box-constrained boundaries of the problem. Necesary for pygmo library
+    def get_bounds(self) -> Tuple[List[float], List[float]]:
+        """Box-constrained boundaries of the problem. Necessary for pygmo library
 
         Returns
         -------
@@ -73,8 +93,14 @@ class PygmoProblem:
     def gradient(self, x: np.ndarray):
         """Gradient in pygmo accepted format
 
-        :param x: input vector
-        :return: gradient
+        Parameters
+        ----------
+        x
+            input vector
+
+        Returns
+        -------
+            gradient
         """
         # return pg.estimate_gradient(lambda x: self.fitness(x), x)
         return self.func.dfdx(x)
@@ -84,29 +110,48 @@ class PygmoProblem:
 class PygmoAlgorithm(Optimizer):
     """Wrapper around the pygmo algorithm class
 
-    :param data: Data-object
-    :param hyperparameters: Dictionary with hyperparamaters
-    :param seed: seed to set the optimizer
-    :param defaults: Default hyperparameter arguments
+    Parameters
+    ----------
+    data
+        ExperimentData-object
+    hyperparameters
+        Dictionary with hyperparameters
+    seed
+        seed to set the optimizer
+    defaults
+        Default hyperparameter arguments
     """
 
+    @staticmethod
+    def _check_imports():
+        _imports.check()
+
     @staticmethod
     def set_seed(seed: int):
         """Set the seed for pygmo
 
-        :param seed: seed for the random number generator
+        Parameters
+        ----------
+        seed
+            seed for the random number generator
         """
         pg.set_global_rng_seed(seed=seed)
 
     def update_step(self, function: Function) -> Tuple[np.ndarray, np.ndarray]:
         """Update step of the algorithm
 
-        :param function: function to be evaluated
-        """
+        Parameters
+        ----------
+        function
+            function to be evaluated
 
+        Returns
+        -------
+            tuple of updated input parameters (x) and objecti value (y)
+        """
         # Construct the PygmoProblem
         prob = pg.problem(
-            PygmoProblem(
+            _PygmoProblem(
                 design=self.data.design,
                 func=function,
                 seed=self.seed,
