@@ -3,14 +3,17 @@
 
 # Standard
 from dataclasses import dataclass
+from typing import List
 
-# Third-party
-import tensorflow as tf
-
-from .adapters.tensorflow_implementations import TensorflowOptimizer
 # Locals
+from .._imports import try_import
+from .adapters.tensorflow_implementations import TensorflowOptimizer
 from .optimizer import OptimizerParameters
 
+# Third-party extension
+with try_import('optimization') as _imports:
+    import tensorflow as tf
+
 #                                                          Authorship & Credits
 # =============================================================================
 __author__ = 'Martin van der Schelling (M.P.vanderSchelling@tudelft.nl)'
@@ -41,3 +44,6 @@ class SGD(TensorflowOptimizer):
             momentum=self.parameter.momentum,
             nesterov=self.parameter.nesterov,
         )
+
+    def get_info(self) -> List[str]:
+        return ['Stable', 'First-Order', 'Single-Solution']
