@@ -1,13 +1,22 @@
 #                                                                       Modules
 # =============================================================================
 
-# Third-party
-import autograd.numpy as np
-from SALib.sample import latin
+# Standard
+from typing import Any, Union
+
+# Third-party core
+import numpy as np
 
 # Locals
+from .._imports import try_import
+from ..design import DesignSpace
 from .sampler import Sampler
 
+# Third-party extension
+with try_import('sampling') as _imports:
+    from SALib.sample import latin
+
+
 #                                                          Authorship & Credits
 # =============================================================================
 __author__ = 'Martin van der Schelling (M.P.vanderSchelling@tudelft.nl)'
@@ -21,6 +30,10 @@ __status__ = 'Stable'
 class LatinHypercube(Sampler):
     """Sampling via Latin Hypercube Sampling"""
 
+    def __init__(self, design: DesignSpace, seed: Union[Any, int] = None):
+        _imports.check()
+        super().__init__(design, seed)
+
     def sample_continuous(self, numsamples: int) -> np.ndarray:
         """Sample from continuous space
 
